@@ -84,7 +84,7 @@ sub printf ($;@) {
     my $fmt   = shift @_ || die "missing format argument";
     if ($self->{-level} >= $level) {
         my ($sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst) = localtime(time());
-        my $id = sprintf("[%04d-%02d-%02d/%02d:%02d:%02d@%05d] ", 
+        my $id = sprintf("[%04d-%02d-%02d/%02d:%02d:%02d@%05d] ",
                          $year+1900, $mon+1, $mday, $hour, $min, $sec, $$);
         $self->{-io}->printf($id . $fmt . "\n", @_);
     }
@@ -204,11 +204,11 @@ sub run ($$;$) {
     }
     else {
         $self->{-log}->printf(3, "system: run: \"$cmd\" ($expires) [CACHE MISS]");
-        $self->{-log}->printf(5, "system: executing command: \"$cmd\""); 
+        $self->{-log}->printf(5, "system: executing command: \"$cmd\"");
         $result = { -stdout => '', -rv => 0 };
         $result->{-stdout} = `$cmd 2>/dev/null`;
         $result->{-rv} = ($? >> 8);
-        $self->{-log}->printf(6, "system: return value: ". $result->{-rv}); 
+        $self->{-log}->printf(6, "system: return value: ". $result->{-rv});
         $self->{-cache}->store($cmd, $expires, $result);
     }
     return $result;
@@ -487,7 +487,7 @@ my $opt = {
     'bindir'    => "/cw/bin",
     'probedir'  => "@libexecdir@/snmpdx",
     'probename' => "*",
-    'mibdir'    => "@datadir@/snmpdx/mibs",
+    'mibdir'    => "@datadir@/snmpdx", # FIXME
     'mibname'   => "snmpdx",
     'logfile'   => "@localstatedir@/snmpdx.log",
     'loglevel'  => 9,
@@ -549,7 +549,7 @@ if (-f $opt->{'config'}) {
         my ($option, $value) = ($line =~ m|^\s*(\S+)\s+(.+?)\s*$|s);
         die "invalid configuration line \"$line\""
             if (not defined($option) or not defined($value));
-        my ($var) = map  { $options{$_} } 
+        my ($var) = map  { $options{$_} }
                     grep { $_ =~ m/^.\|\Q$option\E(=[si])?$/s }
                     keys(%options);
         die "invalid configuration option \"$option\""
@@ -575,7 +575,7 @@ $ctx->{-log}->printf(1, "startup %s %s (%s) on %s",
     $prg->{'name'}, $prg->{'version'}, $prg->{'date'},
     $ctx->{-platform}->id());
 
-#   exception handling support 
+#   exception handling support
 $SIG{__DIE__} = sub {
     my ($err) = @_;
     $err =~ s|\r?\n$||s;
